**Devlog guidelines:**
- All new code needs to be tested and documented. Add daily tasks accordingly.
- The written dissertation (or at least the notes to write it) needs to move along with all the other goals.

# Daily sprint goals

- finish beartype setup

# Tasks for the day

- [ ] finish rewriting all documentation with types

# Notes

- 

# Shutdown and Retrospective

- [ ] test and validate all new code
- [ ] commit to the remote repo
- [ ] make a schedule for tomorrow

**Did anything go wrong? What could have been done better, and how?**
- 